VThemeConfig class

============================================================ VThemeConfig — 放在 v_components 库里的通用主题扩展 ☞ 第三层公共主题配置

只放所有项目都需要的通用配置:

  • 表单样式(光标、hint、label、value)
  • 按钮配置
  • 圆角系统
  • 间距系统

不放业务色(statusDispatch 等),那些是项目特有的。

Inheritance

Constructors

VThemeConfig({TextStyle? labelStyle, TextStyle? valueStyle, TextStyle? requiredStarStyle, IconThemeData? iconTheme, IconThemeData? arrowIconTheme, IconThemeData? clearIconTheme, IconThemeData? pwdEyeIconTheme, double? buttonHeight, double? buttonFontSize, double? buttonRadius, double? buttonPaddingH, double? cellHeight, double? cellTitleWidth, VTabBarStyle? tabBarStyle, double? smallRadius, double? mediumRadius, double? largeRadius, double? circularRadius, double? cardRadius, double? dialogRadius, double? spacingXS, double? spacingSM, double? spacingMD, double? spacingLG, double? spacingXL, Color? successColor, Color? errorColor, Color? warningColor, Color? infoColor, Color? linkColor})
const
VThemeConfig.dark()
factory
VThemeConfig.light()
factory

Properties

arrowIconTheme IconThemeData?
final
buttonFontSize double?
final
buttonHeight double?
final
buttonPaddingH double?
final
buttonRadius double?
final
cardRadius double?
final
cellHeight double?
final
cellTitleWidth double?
final
circularRadius double?
final
clearIconTheme IconThemeData?
final
dialogRadius double?
final
errorColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
iconTheme IconThemeData?
final
infoColor Color?
final
labelStyle TextStyle?
final
largeRadius double?
final
linkColor Color?
final
mediumRadius double?
final
pwdEyeIconTheme IconThemeData?
final
requiredStarStyle TextStyle?
final
resolvedButtonRadius double
no setter
resolvedCardRadius double
no setter
resolvedDialogRadius double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smallRadius double?
final
spacingLG double?
final
spacingMD double?
final
spacingSM double?
final
spacingXL double?
final
spacingXS double?
final
successColor Color?
final
tabBarStyle VTabBarStyle?
final
type Object
The extension's type.
no setterinherited
valueStyle TextStyle?
final
warningColor Color?
final

Methods

copyWith({Color? inputCursorColor, TextStyle? hintStyle, TextStyle? labelStyle, TextStyle? valueStyle, TextStyle? requiredStarStyle, IconThemeData? iconTheme, IconThemeData? arrowIconTheme, IconThemeData? clearIconTheme, IconThemeData? pwdEyeIconTheme, double? buttonHeight, double? buttonFontSize, double? buttonRadius, double? buttonPaddingH, double? cellHeight, double? cellTitleWidth, VTabBarStyle? tabBarStyle, double? smallRadius, double? mediumRadius, double? largeRadius, double? circularRadius, double? cardRadius, double? dialogRadius, double? spacingXS, double? spacingSM, double? spacingMD, double? spacingLG, double? spacingXL, Color? successColor, Color? errorColor, Color? warningColor, Color? infoColor, Color? linkColor}) VThemeConfig
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant VThemeConfig? other, double t) VThemeConfig
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) VThemeConfig