VBottomSheetContent class

@author: wzp_vicky @time: 2026年6月9日 @version: V1.0 @description: VBottomSheet 内部容器组件 负责处理顶部圆角、背景色、拖拽手柄、内边距,以及可滚动场景下的 scrollController 接入

Inheritance

Constructors

VBottomSheetContent({Key? key, required Widget child, double? height, bool showDragHandle = true, double? borderRadius, Color? backgroundColor, EdgeInsetsGeometry? padding, ScrollController? scrollController})
const

Properties

backgroundColor Color?
背景色,为 null 时从主题读取
final
borderRadius double?
顶部圆角,为 null 时从主题读取
final
child Widget
面板内容
final
hashCode int
The hash code for this object.
no setterinherited
height double?
固定高度,为 null 时自适应内容(最大450)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
child 内边距
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
滚动控制器,拖拽伸缩模式下由 DraggableScrollableSheet 提供
final
showDragHandle bool
是否显示顶部拖拽手柄
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited