build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
final theme = Theme.of(context);
// 圆角优先取参数,其次取主题 dialogRadius,最后兜底 16
final effectiveRadius = borderRadius ?? context.vTheme.dialogRadius ?? 16.0;
// 背景色优先取参数,其次取主题 surface 色
final effectiveBg = backgroundColor ?? theme.colorScheme.surface;
final effectivePadding = padding ?? const EdgeInsets.all(16);
// 组装面板主体
Widget content = Container(
decoration: BoxDecoration(
color: effectiveBg,
borderRadius: BorderRadius.vertical(
top: Radius.circular(effectiveRadius),
),
),
child: scrollController != null
// 可滚动模式:手柄和内容放进同一个滚动视图,拖手柄/拖内容都能伸缩面板
? _buildScrollableBody(theme, effectivePadding)
// 普通模式:手柄在上,内容在下
: Column(
mainAxisSize: MainAxisSize.min,
children: [
if (showDragHandle) _buildDragHandle(theme),
Flexible(child: Padding(padding: effectivePadding, child: child)),
],
),
);
// 根据高度模式包裹
return _wrapByHeight(context, content);
}