VButton class

Inheritance

Constructors

VButton({Key? key, String text = '', String? textColor, String? bgColor, String? disabledBgColor, String? imageBg, bool hasBorder = false, TextStyle? textStyle, BorderRadius? radius, Widget? child, double? width, Color? color, Color? highlightColor, Color? splashColor, Gradient? gradient, BoxBorder? border, EdgeInsets? padding, EdgeInsets margin = EdgeInsets.zero, String? textColorStr, VButtonType type = VButtonType.primary, bool block = false, bool round = false, bool disabled = false, bool loading = false, VLoadingType loadingType = VLoadingType.circular, Color? loadingColor, Widget? icon, VIconPosition iconPosition = VIconPosition.left, double? height, double? fontSize, VoidCallback? onPressed})
const

Properties

bgColor String?
final
block bool
final
border BoxBorder?
final
child Widget?
final
color Color?
final
disabled bool
final
disabledBgColor String?
final
fontSize double?
final
gradient Gradient?
final
hasBorder bool
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
highlightColor Color?
final
icon Widget?
final
iconPosition VIconPosition
final
imageBg String?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading bool
final
loadingColor Color?
final
loadingType VLoadingType
final
margin EdgeInsets
final
onPressed VoidCallback?
final
padding EdgeInsets?
final
radius BorderRadius?
final
round bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splashColor Color?
final
text String
final
textColor String?
final
textColorStr String?
final
textStyle TextStyle?
final
type VButtonType
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited