VCountDownBtnState class
- Inheritance
-
- Object
- State<
VCountDownBtn> - VCountDownBtnState
- Mixed-in types
Constructors
Properties
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
-
phaseNotifier
→ ValueNotifier<
CountDownPhase> -
当前阶段通知器(状态)
finalinherited
-
remainingNotifier
→ ValueNotifier<
int> -
剩余秒数通知器,外部可监听实现局部刷新(最小粒度的变更通知)
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → VCountDownBtn
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createTicker(
TickerCallback onTick) → Ticker -
Creates a ticker with the given callback.
inherited
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant VCountDownBtn oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
disposeCountDown(
) → void -
释放资源,需在 dispose 中调用
inherited
-
initCountDown(
) → void -
初始化 Ticker,需在 initState 中调用
inherited
-
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCountDownFinish(
) → void -
倒计时结束回调,子类可重写
override
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
reset(
) → void - 外部调用:手动重置倒计时(如切换手机号场景)
-
resetCountDown(
) → void -
重置倒计时到空闲态
inherited
-
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
startCountDown(
int seconds) → void -
开始倒计时
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited