VGuideTarget class

引导高亮目标:用 widget 的 GlobalKey 描述一个需要挖洞高亮的区域。

业务方只需给目标 widget 挂 GlobalKey,再用本类描述「挖洞外扩 padding + 圆角 radius」, 交给 VGuide.show 的 targets,组件内部会自动换算成屏幕坐标的 RRect。

Constructors

VGuideTarget(GlobalKey<State<StatefulWidget>> key, {double padding = 6, double radius = 8})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key GlobalKey<State<StatefulWidget>>
目标 widget 的 key(该 widget 必须已完成布局)
final
padding double
挖洞区域相对目标 widget 四周外扩的内边距,默认 6
final
radius double
挖洞圆角,圆形高亮传一个很大的值(如 999)即可,默认 8
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited