VStepper class

@author: wzp_vicky @time: 2022年11月4日23:30:48 @version: V1.1 @description: 一个自定义的stepper组件。

首先:flutter提供了一个stepper组件,但是呢,个人觉得人家这个才是严格意义的stepper,而且呢
      小程序现采用的有赞组件里面的stepper也跟flutter的很类似
但是易流的这种流程貌似更加适合这种,所以就仿照小程序现有的那组件做一个

需要表示是不是高亮点 线的颜色修改 @author: wzp_vicky @time: 2024年7月17日17:52:23 @version: V2 @description: 增加左侧时间

Inheritance

Constructors

VStepper({double? titleLineHeight, double? lineWidth, double? circleDiameter, double? circleMargin, String? normalLineColor, String? lightLineColor, bool isShowLastLine = false, bool isOnlyLightCircle = true, int lightIndex = 0, Function? createTitle, Function? createContent, int stepCount = 3, double? leftWidth, bool isShowLeft = false, String? leftTxt, Function? createLeftTxt})

Properties

circleDiameter double
final
circleMargin double
final
createContent Function?
final
createLeftTxt Function?
final
createTitle Function?
final
hashCode int
The hash code for this object.
no setterinherited
isOnlyLightCircle bool
final
isShowLastLine bool
final
isShowLeft bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leftTxt String?
final
leftWidth double
final
lightIndex int
final
lightLineColor String
final
lineWidth double
final
normalLineColor String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepCount int
final
titleLineHeight double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getLineColor(int index) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited