VThemeSwitchStyle enum

============================================================ VThemeSwitchButton — 主题切换按钮组件

路径:lib/widgets/theme_switch/v_theme_switch_button.dart

功能:

  • 带 AnimatedSwitcher 动画的主题切换按钮
  • 支持亮/暗切换、多主题切换两种模式
  • 动画可配置(时长、曲线、过渡效果)
  • 自动监听 VThemeController 状态变化

    切换按钮样式枚举
Inheritance
Available extensions

Values

lightDark → const VThemeSwitchStyle

亮/暗图标切换(太阳/月亮)

palette → const VThemeSwitchStyle

调色盘图标(点击弹出主题选择)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VThemeSwitchStyle>
A constant List of the values in this enum, in order of their declaration.