VCellArrowDirection enum
@author: wzp_vicky @time: 2022年10月25日17:38:28 @version: V1.1 @description:仿有赞组件的cell
@author: wzp_vicky @time: 2024年6月22日14:13:32 @version: V1.2 @description:把style更加精细化,自定义的时候支持垂直方向自适应
@author: wzp_vicky @time: 2024年10月30日16:56:24 @version: V1.2 @description:增加属性disable和disableHiddenArrow适用于禁用的场景
@author: wzp_vicky @time: 2025年7月11日15:22:10 @version: V1.3 @description: 右侧箭头跟右边文字的间距减小
@author: wzp_vicky @time: 2026年3月13日12:27:33 @version: V1.4 @description: 增加arrowDirection给右侧箭头添加方向
箭头方向
Values
- right → const VCellArrowDirection
- down → const VCellArrowDirection
- up → const VCellArrowDirection
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VCellArrowDirection> - A constant List of the values in this enum, in order of their declaration.